@@ -13,6 +13,7 @@ import platform as _platform
 import signal as _signal
 import sys as _sys
 import warnings as _warnings
+from pathlib import Path as _Path
 
 import docarray as _docarray
 
@@ -64,7 +65,7 @@ elif _sys.version_info >= (3, 8, 0) and _platform.system() == 'Darwin':
 # this is managed by git tag and updated on every release
 # NOTE: this represents the NEXT release version
 
-__version__ = '3.6.15'
+__version__ = '3.7.6'
 
 # do not change this line manually
 # this is managed by proto/build-proto.sh and updated on every execution
@@ -107,6 +108,7 @@ __jina_env__ = (
     'JINA_RANDOM_PORT_MIN',
     'JINA_DISABLE_HEALTHCHECK_LOGS',
     'JINA_LOCKS_ROOT',
+    'JINA_OPTOUT_TELEMETRY',
 )
 
 __default_host__ = _os.environ.get(
@@ -127,6 +129,9 @@ __args_executor_init__ = {'metas', 'requests', 'runtime_args'}
 __resources_path__ = _os.path.join(
     _os.path.dirname(_sys.modules['jina'].__file__), 'resources'
 )
+__cache_path__ = f'{_os.path.expanduser("~")}/.cache/{__package__}'
+if not _Path(__cache_path__).exists():
+    _Path(__cache_path__).mkdir(parents=True, exist_ok=True)
 
 _names_with_underscore = [
     '__version__',
