@@ -16,18 +16,23 @@ from functools import lru_cache, wraps
 from pathlib import Path
 from typing import Dict, Optional, Tuple
 from urllib.parse import urljoin, urlparse
-from urllib.request import Request, urlopen
 
-from jina import __resources_path__
+from jina import __cache_path__, __resources_path__
 from jina.enums import BetterEnum
 from jina.helper import get_request_header as _get_request_header_main
+from jina.hubble.requirements import (
+    check_env_variable,
+    expand_env_variables,
+    get_env_variables,
+    parse_requirement,
+)
 from jina.importer import ImportExtensions
 from jina.logging.predefined import default_logger
 
 
 @lru_cache()
 def _get_hub_root() -> Path:
-    hub_root = Path(os.environ.get('JINA_HUB_ROOT', Path.home().joinpath('.jina')))
+    hub_root = Path(os.environ.get('JINA_HUB_ROOT', __cache_path__))
 
     if not hub_root.exists():
         hub_root.mkdir(parents=True, exist_ok=True)
@@ -94,27 +99,11 @@ def get_download_cache_dir() -> Path:
 
 @lru_cache()
 def _get_hubble_base_url() -> str:
-    """Get base Hubble Url from api.jina.ai or os.environ
+    """Get base Hubble Url from os.environ or constants
 
     :return: base Hubble Url
     """
-    if 'JINA_HUBBLE_REGISTRY' in os.environ:
-        u = os.environ['JINA_HUBBLE_REGISTRY']
-    else:
-        try:
-            req = Request(
-                'https://api.jina.ai/hub/hubble.json',
-                headers={'User-Agent': 'Mozilla/5.0'},
-            )
-            with urlopen(req) as resp:
-                u = json.load(resp)['url']
-        except:
-            default_logger.critical(
-                'Can not fetch the Url of Hubble from `api.jina.ai`'
-            )
-            raise
-
-    return u
+    return os.environ.get('JINA_HUBBLE_REGISTRY', 'https://api.hubble.jina.ai')
 
 
 @lru_cache()
@@ -189,6 +178,23 @@ def parse_hub_uri(uri_path: str) -> Tuple[str, str, str, str]:
     return scheme, name, tag, secret
 
 
+def replace_secret_of_hub_uri(uri_path: str, txt: str = '<secret>') -> str:
+    """Replace the secret of the Jina Hub URI.
+
+    :param uri_path: the uri of Jina Hub URI
+    :param txt: text to replace
+    :return: the new URI
+    """
+
+    try:
+        secret = parse_hub_uri(uri_path)[-1]
+        if secret:
+            return uri_path.replace(secret, txt)
+    except ValueError:
+        pass  # ignore if the URI is not a valid Jina Hub URI
+    return uri_path
+
+
 def is_valid_huburi(uri: str) -> bool:
     """Return True if it is a valid Hubble URI
 
@@ -485,9 +491,52 @@ def is_requirements_installed(
     return True
 
 
-def _get_install_options(requirements_file: 'Path', excludes: Tuple[str] = ('jina',)):
-    from .requirements import parse_requirement
+def get_requirements_env_variables(requirements_file: 'Path') -> list:
+    """get the env variables in requirements.txt
+    :param requirements_file: the requirements.txt file
+    :return: List of env variables in requirements.txt
+    """
+    env_variables = []
+    with requirements_file.open() as requirements:
+        for req in requirements:
+            req = req.strip()
+            if (not req) or req.startswith('#'):
+                continue
+            else:
+                variables = get_env_variables(req)
+                env_variables.extend(variables)
 
+    return env_variables
+
+
+def check_requirements_env_variable(env_variable: str) -> bool:
+    """
+    check the environment variables is limited
+    to uppercase letter and number and the `_` (underscore).
+    :param env_variable: env_variable in the requirements.txt file
+    :return: True or False if not satisfied
+    """
+    return check_env_variable(env_variable)
+
+
+def replace_requirements_env_variables(requirements_file: 'Path') -> list:
+    """replace the environment variables in requirements.txt
+    :param requirements_file: the requirements.txt file
+    :return: List of replaced env variables in requirements.txt
+    """
+    env_variables = []
+    with requirements_file.open('r') as requirements:
+        for line in requirements.readlines():
+            line = line.strip()
+            if (not line) or line.startswith('#'):
+                continue
+            else:
+                line = expand_env_variables(line)
+                env_variables.append(line)
+    return env_variables
+
+
+def _get_install_options(requirements_file: 'Path', excludes: Tuple[str] = ('jina',)):
     with requirements_file.open() as requirements:
         install_options = []
         install_reqs = []
@@ -496,13 +545,14 @@ def _get_install_options(requirements_file: 'Path', excludes: Tuple[str] = ('jin
             if (not req) or req.startswith('#'):
                 continue
             elif req.startswith('-'):
-                install_options.extend(req.split(' '))
+                for index, item in enumerate(req.split(' ')):
+                    install_options.append(expand_env_variables(item))
             else:
-                req_spec = parse_requirement(req)
+                expand_req = expand_env_variables(req)
+                req_spec = parse_requirement(expand_req)
 
                 if req_spec.project_name not in excludes or len(req_spec.extras) > 0:
-                    install_reqs.append(req)
-
+                    install_reqs.append(expand_req)
     return install_reqs, install_options
 
 
@@ -621,7 +671,7 @@ We can not discover any Executor in your uploaded bundle. This is often due to o
   - The bundle did not contain any valid executor.
   - The config.yml's `jtype` is mismatched with the actual Executor class name.
     For more information about the expected bundle structure, please refer to the documentation.
-    https://docs.jina.ai/fundamentals/executor/repository-structure/
+    https://docs.jina.ai/fundamentals/executor/executor-files/#multiple-python-files-yaml 
 '''
         msg += '''
 For more detailed information, you can try the `executor-normalizer` locally to see the root cause.
